from setuptools import setup

setup(
    name='rbxflip',
    version='1.0.3',
    description='Python package for interacting with the RBXFlip API',
    author='Angelics',
    url='https://github.com/Angelics9999/rbxflip',
    packages=['rbxflip'],
    install_requires=['requests'],
)
